@@ -437,7 +437,7 @@ def set_charset():
 
         elif choice == '4':
             file = input('\n\nEnter File containing characterset :')
-            file = os.getcwd() + file
+            os.chdir(..)
             fil = ''
             try:
                 with open(file,'r') as f:
@@ -449,6 +449,7 @@ def set_charset():
                 
                 p.A = tuple(p.A)
 
+                os.chdir('PyPassDB')
             except FileNotFoundError as e:
                 print('File Not Found!')
                 time.sleep(3)
