@@ -15,38 +15,45 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-''' 
-Pysecret is a simple secret sharing tool using python3 developed by M.Anish only.
-Converts secrets to more than one code . The secret can't be recovered even if a single code is missing.
-'''
+''' Pysecret is a simple secret sharing tool using python3 developed by M.Anish only.
+    Converts secrets to more than one code . The secret can't be recovered even if a single code is missing'''
 
 try:
     import os
+    import sys
     import getpass
     import secrets
-    import sys
 except ImportError:
     print(' Critical Error: Required Modules Not found!\n')
     x = input(' Press any key to continue...')
     sys.exit(1)
 
-A=('A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z','0','1','2','3','4','5','6','7','8','9','a','b','c','d','e','f','g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v','w','x','y','z','!','@','#','$','%','^','&','*','(',')','-','+','_','=','{','}','[',']','<','>','?','|')
+A = ('A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z','0','1','2','3','4','5','6','7','8','9','a','b','c','d','e','f','g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v','w','x','y','z','!','@','#','$','%','^','&','*','(',')','-','+','_','=','{','}','[',']','<','>','?','|')
 
-# converts Alphanumeric characters to numbers of base 84    
+# convert Alphanumeric characters to numbers of base which is equal to length of variable A.    
 def f(x):
   store = []
+
   for s in x:
     count = 0
-    for i in range(84):
-        if A[i] == s:
-          store.append(i)
-          count = 1
-          break
+    for i in range(len(A)):
+        if A == ('A','B','C','D','E','F','G','H','I','J','K','L','M','N','o','P','Q','R','S','T','U','V','W','X','Y','Z','0','1','2','3','4','5','6','7','8','9'):
+            if A[i].lower() == s.lower():
+                store.append(i)
+                count = 1
+                break
+        else:
+
+            if A[i] == s:
+                store.append(i)
+                count = 1
+                break
+
     if count == 0:
       store.append(' ')
   return tuple(store)                
     
-# converts base 84 numbers to alphanumeric charactors.
+# converts numbers to alphanumeric charactors.
 def rf(x):
     store = []
     q = ''
@@ -60,7 +67,7 @@ def rf(x):
     
 # generates a key without keyfile.
 def ikey(x):
-    seed = list(range(84))
+    seed = list(range(len(A)))
     masterkey = []
     for i in range(len(x)):
         masterkey.append(secrets.choice(seed))
@@ -72,13 +79,13 @@ def en(msg):
     x = f(msg)
     y = ikey(msg)
     for i in range(len(x)):
-            if type(x[i]) == int :
-                ciphertxt.append(((x[i] + y[i]) % 84))
+            if type(x[i]) is int :
+                ciphertxt.append(((x[i] + y[i]) % len(A)))
             else:
                 ciphertxt.append(' ')
     ctxt = rf(tuple(ciphertxt))
     shk = rf(y)
-    return (ctxt,shk)
+    return (ctxt, shk)
 
 # decrypts a given encrypted string and returns a plaintxt as output.
 def de(c, k):
@@ -87,8 +94,8 @@ def de(c, k):
     y = f(k)
     if len(x) <= len(y):
         for i in range(len(x)):
-            if type(x[i]) == int and type(y[i]) == int:
-                ciphertxt.append(((x[i] - y[i]) % 84))
+            if type(x[i]) is int and type(y[i]) is int:
+                ciphertxt.append(((x[i] - y[i]) % len(A)))
             else:
                 ciphertxt.append(' ')
     else:
@@ -105,18 +112,19 @@ def sprocess():
     while 1:
         try:
             x = int(input('\n Enter the number of backup codes(atmost 10,atleast 2):'))
-            if 1 < x< 11:
+            if(x < 11)and(x > 1):
                 break
         except ValueError:
             print('\n Please enter a valid integer greater than 1 but less than or equal to 10!\n')
     msg = getpass.getpass(' Enter the master password:')
+
     table += list(en(msg))
-    for i in range(2, x):
+    for i in range(2,x):
         tmp = table[-1]
         table.pop()
         table += list(en(tmp))
     for i in range(len(table)):
-        print('CODE', i + 1, ':', table[i])
+        print('CODE',i + 1,':',table[i])
 
 # function for secret combining interface.
 def cprocess():
@@ -127,12 +135,12 @@ def cprocess():
     while 1:
         try:
             x = int(input('\n Enter no. of backup codes to combine(atmost 10,atleast 2):'))
-            if 1 < x < 11:
+            if(x < 11)and( x > 1):
                 break
         except ValueError:
                 print('\n Please enter a valid integer greater than 1 but less than or equal to 10!\n')
     for i in range(x):
-            table.append(getpass.getpass(str(' Enter Code ' + str(i + 1) + ':')))
+            table.append(getpass.getpass(str(' Enter Code '+str(i + 1)+':')))
     for i in range(x - 1):
             hook = []
             a, b = table[-2], table[-1]
@@ -159,14 +167,15 @@ def tske():
 def tskf():
     print('\n<-----Task Failed !----->\n')
 
+
 def wait():
-    x = input('Press any key to continue...\n')
+      x = input('\n Press any key to continue...\n')
 
 def display(file):
-        if os.path.exists(file) == False:
-           print('Error: ' + file + ' not found!\n')
+        if os.path.exists(file) is False:
+           print('Error: '+ file +' not found!')
            wait()
-           exit(1)
+           sys.exit(1)
         with open(file,'r') as f:
             s = f.read(1024)
             print(s)
@@ -193,7 +202,7 @@ def mm():
    else:
       print(' please enter 1 or 2 or \'c\' to exit!')
       mm()
-
+   sys.exit(0)
     
    
         
